@@ -11,4 +11,6 @@ from . import pp
 from . import tl
 from . import pl
 from . import datasets
+from . import get
 from . import settings
+from .settings import set_figure_pubready
