@@ -2,7 +2,7 @@ from .trajectory import graph, trajectory, trajectory_3d
 from .features import trends, single_trend
 from .test_association import test_association
 from .modules import modules
-from .milestones import milestones, milestones_graph
+from .milestones import milestones
 from .slide_cors import slide_cors
 from .synchro_path import synchro_path
 from .test_fork import test_fork
