@@ -137,9 +137,9 @@ def test_fork(
 
         if n_map == 1:
             logg.info("    single mapping")
-        ## Diff expr between forks
-
-        df = adata.uns["pseudotime_list"][str(m)]
+            df = adata.obs.loc[:, ["t", "seg"]]
+        else:
+            df = adata.uns["pseudotime_list"][str(m)]
         edges = graph["pp_seg"][["from", "to"]].astype(str).apply(tuple, axis=1).values
         img = igraph.Graph()
         img.add_vertices(
@@ -162,7 +162,7 @@ def test_fork(
         else:
             brcells["w"] = matw[gene, :][:, graph["cells_fitted"]]
 
-        brcells.drop(["seg", "edge"], axis=1, inplace=True)
+        brcells.drop(["seg"], axis=1, inplace=True)
 
         if rescale:
             for i in brcells.i.unique():
@@ -221,9 +221,6 @@ def test_fork(
 
         upreg_stat = upreg_stat + [pd.concat(leaves_stat).loc[genes]]
 
-    # summarize fork statistics
-    # fork_stat=list(map(lambda x: pd.DataFrame(x,index=genes,columns=["effect","p_val"]),fork_stat))
-
     fdr_l = list(
         map(
             lambda x: pd.Series(
@@ -521,7 +518,10 @@ def activation(
     allact = []
 
     def activation_map(m):
-        df = adata.uns["pseudotime_list"][str(m)]
+        if n_map == 1:
+            df = adata.obs.loc[:, ["t", "seg"]]
+        else:
+            df = adata.uns["pseudotime_list"][str(m)]
         acti = pd.Series(0, index=stats.index)
 
         for leave in leaves:
@@ -763,7 +763,9 @@ def activation_lm(
 
         if n_map == 1:
             logg.info("    single mapping")
-        df = adata.uns["pseudotime_list"][str(m)]
+            df = adata.obs.loc[:, ["t", "seg"]]
+        else:
+            df = adata.uns["pseudotime_list"][str(m)]
         edges = graph["pp_seg"][["from", "to"]].astype(str).apply(tuple, axis=1).values
         img = igraph.Graph()
         img.add_vertices(
